tdsynctest

package
v1.15.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: BSD-2-Clause Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Test

func Test(t *td.T, f func(t *td.T))

Test is a wrapper around synctest.Test.

The t param of f inherits the configuration of t.

t.TB (set by td.NewT, td.Assert, td.Require, …) must be a *testing.T instance.

func TestAssertRequire

func TestAssertRequire(t *td.T, f func(assert, require *td.T))

TestAssertRequire is a wrapper around synctest.Test.

The assert and require params of f inherit the configuration of t, except that a failure is never fatal using assert and always fatal using require.

t.TB (set by td.NewT, td.Assert, td.Require, …) must be a *testing.T instance.

func Wait

func Wait()

Wait simply calls synctest.Wait. It only exists to avoid to import testing/synctest.

Types

This section is empty.

Jump to