Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Test ¶
Test is a wrapper around synctest.Test.
The t param of f inherits the configuration of t.
t.TB (set by td.NewT, td.Assert, td.Require, …) must be a *testing.T instance.
func TestAssertRequire ¶
TestAssertRequire is a wrapper around synctest.Test.
The assert and require params of f inherit the configuration of t, except that a failure is never fatal using assert and always fatal using require.
t.TB (set by td.NewT, td.Assert, td.Require, …) must be a *testing.T instance.
func Wait ¶
func Wait()
Wait simply calls synctest.Wait. It only exists to avoid to import testing/synctest.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.